/*
	ProWesS, PROGS Windowing System
	PROforma, PROGS Font & Raster Manager

	PFconfig : utility program for ProWesS package
		allows easy configuration of PROforma

	written by Joachim Van der Auwera for PROGS
	(c) 1996 by PROGS, Professional & Graphical Software
	29.09.1996 started
*/

#include <io.h>
#include <mem.h>
#include <thing.h>
#include <PROforma.h>
#include <ProWesS.h>

#define catch(x) do { if (err=(x)) return err; } while (0)
#define MAX_LINE 100
#define MAX_UNITSTRING 20
#define UNIT_MM 1
#define UNIT_IN 2
#define UNIT_PT 3

typedef struct _Lines {
	struct _Lines *next;
	char line[MAX_LINE];
} Lines;

typedef struct _CLines {
	struct _CLines *next;
	char driver[PF_MAXDRIVERNAME];
	char device[IO_MAXFULLNAME];
	pt xsize, ysize;
	pt xmarg, ymarg;
} CLines;

typedef struct {
	char changed;					/* has configuration changed */
	char printer[PF_MAXDRIVERNAME]; /* default printer driver */
	int newdef; 					/* set when prev command was 'd' */
	int memory; 					/* max/min amount of memory for Gstate */
	int cachesize, cachecount;		/* font cache parameters */
	int colcache;					/* size of colour cache */
	Lines *fpath;					/* search directories for fonts */
	Lines *dpath;					/* search directories for drivers */
	Lines *rfont;					/* resident fonts */
	Lines *drivers; 				/* drivers which are loaded */
	Lines *fonts;					/* font names & files, separated by '\0' */
	CLines *config; 				/* config info for the printer drivers */
	Chunks lines;					/* memory for the lines, should be */
									/* suitable for Lines & CLines !! */

	/* aid fields for driver config */
	int unit;						/* default unit in dcfg */
	CLines *current;				/* current entry (or NULL) */
	char driver[PF_MAXDRIVERNAME];
	char device[IO_MAXFULLNAME];
	pt xsize,ysize,xmarg,ymarg;
	PWObject oxsize,oysize,oxmarg,oymarg,odevice;
} Global;

/* external functions */
Error DriverSelect(char *menu_name, char screen, char def, char *drivername);
Error DisplayError(Error error);

Error DriverAdd(Global *g);
Error PrinterConfig(Global *g);
Error PrinterDefault(Global *g);
Error ConfigRead(Global *g);
Error ConfigWrite(Global *g);
Error Memory(Global *g);
Error FontAdd(Global *g);
Error FontPath(Global *g);
Error LineAdd(Global *g, char *line, Lines **base);
