/*
	utility program for the ProWesS loader (during installation)

	RFILE : get a filename from the user. The full filename (including
			directory is poured into a filename).

	The program needs a few parameters :
		name of global variable to set
		[ -title value ]
		[ -default value ]
		[ -dir value ]
		[ -exte extensions ]
		[ -not ]
	A possible -path parameter is skipped.

	written by Joachim Van der Auwera for PROGS
	(c) 1996 by PROGS, Professional & Graphical Software
	started 25 August 1996
*/

#include <str_h>
#include <mem_h>
#include <io_h>
#include <thing_h>
#include <ProWesS.h>

#define catch(x) if (err=(x)) return err; else

#define GLOBAL_NAME "Global Variables"
#define GLOBAL_GET	0x47455420	/* "GET " */
#define GLOBAL_SET	0x53455420	/* "SET " */

Error set(PWObject object, char *dir, char *name)
{
	Error err;
	char *val;
	Channel chid;

	PWQuery(object,PW_OBJECT_AUXILIARY,&val);
	err=IOOpenPath(name,OPEN_READ,dir,&chid);
	if (err) return ERR_OK;
	IOName(chid,val+128,val);
	STRAppend(val+128,val);
	return IOClose(chid);
}

Error init(char *param)
{
	Error err;
	char **params;
	char *name=NULL, *defval="", *title="select file";
	char *dir="", *exte="";
	char value[256]="";
	int notst=PW_STATUS_AVAILABLE;
	PWObject win, obj;
	int i;

	/* pars the command line parameters */
	catch( STRBreak(param,&params) );
	for (i=0 ; params[i] ; i++)
	{
		if (STRSameCI("-path",params[i]))
		{
			if (!params[++i]) return ERR_IPAR;
		}
		else if (STRSameCI("-title",params[i]))
		{
			if (params[i++]) title=params[i]; else return ERR_IPAR;
		}
		else if (STRSameCI("-default",params[i]))
		{
			if (params[i++]) defval=params[i]; else return ERR_IPAR;
		}
		else if (STRSameCI("-dir",params[i]))
		{
			if (params[i++]) dir=params[i]; else return ERR_IPAR;
		}
		else if (STRSameCI("-exte",params[i]))
		{
			if (params[i++]) exte=params[i]; else return ERR_IPAR;
		}
		else if (STRSameCI("-not",params[i]))
			notst=PW_STATUS_SELECTED;
		else
			name=params[i];
	}
	if (!name) return ERR_IPAR;

	catch( PWCreate(NULL,&win,PW_TYPE_FILESELECT,
					PW_FILESELECT_TITLE_TEXT, title,
					PW_FILESELECT_ACTION, set,
					PW_OBJECT_AUXILIARY, value,
					PW_FILESELECT_FILENAME, defval,
					PW_FILESELECT_DIRECTORY, dir,
					PW_FILESELECT_EXTENSION, exte,
					PW_FILESELECT_NOT_STATUS, notst,
					NULL) );
	catch( PWChange(win,PW_FILESELECT_ACTIVATE,NULL) );

	return THINGCall(GLOBAL_NAME,GLOBAL_SET,2,name,value);
}
