/*
	utility program for the ProWesS loader (during installation)

	RSTRING : read a string. The value is then poured into a Global Variable

	The program needs a few parameters :
		name of global variable to set
		[ -request value ]
		[ -default value ]
		[ -maxlen value ] (maximum is 256)
	A possible -path parameter is skipped.

	written by Joachim Van der Auwera for PROGS
	(c) 1996 by PROGS, Professional & Graphical Software
	started 10 July 1996
*/

#include <str_h>
#include <mem_h>
#include <io_h>
#include <thing_h>
#include <ProWesS.h>

#define catch(x) if (err=(x)) return err; else

#define GLOBAL_NAME "Global Variables"
#define GLOBAL_GET	0x47455420	/* "GET " */
#define GLOBAL_SET	0x53455420	/* "SET " */

Error exit(PWObject object)
{
	return PWChange(object,PW_SYSTEM_BREAKDOWN,NULL);
}

Error init(char *param)
{
	Error err;
	char **params;
	char *name=NULL, *request=NULL, *defval="", *title="edit string";
	char value[256]; int maxlen=256;
	PWObject win, obj;
	int i;

	/* pars the command line parameters */
	catch( STRBreak(param,&params) );
	for (i=0 ; params[i] ; i++)
	{
		if (STRSameCI("-path",params[i]))
		{
			if (!params[++i]) return ERR_IPAR;
		}
		else if (STRSameCI("-request",params[i]))
		{
			if (params[i++]) request=params[i]; else return ERR_IPAR;
		}
		else if (STRSameCI("-default",params[i]))
		{
			if (params[i++]) defval=params[i]; else return ERR_IPAR;
		}
		else if (STRSameCI("-maxlen",params[i]))
		{
			if (params[i++])
				STRFormatGet(params[i],NULL,"%d",&maxlen);
			else
				return ERR_IPAR;
		}
		else
			name=params[i];
	}
	if (!name) return ERR_IPAR;

	catch( PWCreate(NULL,&win,PW_TYPE_OUTLINE,
					PW_TITLE_TEXT, title,
					PW_OUTLINE_QUIT,
					NULL) );
	if (request) catch( PWCreate(win,NULL,PW_TYPE_INFOSTRING,
					PW_INFOSTRING_TEXT, request,
					NULL) );
	catch( PWCreate(win,&obj,PW_TYPE_DIRECT_EDLINE,
					PW_EDLINE_SET, defval,
					PW_EDLINE_MAXLENGTH, maxlen,
					PW_EDLINE_ACTION_AFTER, exit,
					NULL) );

	PWActivate(win);

	PWChange(obj,PW_EDLINE_GET,256,value,NULL);
	return THINGCall(GLOBAL_NAME,GLOBAL_SET,2,name,value);
}
